import request from '../../utils/request'

export function yzQuery(data) {
  return request({
    url: '/yzActOrder/queryYZ',
    method: 'post',
    data,
  })
}

export function yzModifyApply(data) {
  return request({
    url: '/yzActOrder/yzModifyApply',
    method: 'post',
    data,
  })
}

export function chaKanZhuangTai(
  code,
  actOrderNo,
  inpatientNo,
  currentPage,
  pageSize
) {
  return request({
    url: '/yzActOrder/chaKanZhuangTai',
    method: 'get',
    params: { code, actOrderNo, inpatientNo, currentPage, pageSize },
  })
}

export function danGeShenQing(data) {
  return request({
    url: '/yzActOrder/danGeShenQing',
    method: 'post',
    data,
  })
}
